@@ -18,35 +18,38 @@
 #define QGSAUTHIMPORTIDENTITYDIALOG_H
 
 #include <QDialog>
+#include "qgis_sip.h"
 #include "ui_qgsauthimportidentitydialog.h"
 
 #include <QSslCertificate>
 #include <QSslKey>
 
 #include "qgsauthconfig.h"
+#include "qgis_gui.h"
 
-/** \ingroup gui
- * Widget for importing an identity certificate/key bundle into the authentication database
+/**
+ * \ingroup gui
+ * \brief Widget for importing an identity certificate/key bundle into the authentication database.
  */
 class GUI_EXPORT QgsAuthImportIdentityDialog : public QDialog, private Ui::QgsAuthImportIdentityDialog
 {
     Q_OBJECT
 
   public:
-    /** Type of identity being imported */
+    //! Type of identity being imported
     enum IdentityType
     {
       CertIdentity = 0,
     };
 
-    /** Type of bundles supported */
+    //! Type of bundles supported
     enum BundleTypes
     {
       PkiPaths = 0,
       PkiPkcs12 = 1,
     };
 
-    /** Type of certificate/bundle validity output */
+    //! Type of certificate/bundle validity output
     enum Validity
     {
       Valid,
@@ -56,22 +59,21 @@ class GUI_EXPORT QgsAuthImportIdentityDialog : public QDialog, private Ui::QgsAu
 
     /**
      * Construct a dialog for importing identities
-     * @param identitytype Type of the identity to import
-     * @param parent Parent widget
+     * \param identitytype Type of the identity to import
+     * \param parent Parent widget
      */
-    explicit QgsAuthImportIdentityDialog( QgsAuthImportIdentityDialog::IdentityType identitytype,
-                                          QWidget *parent = nullptr );
-    ~QgsAuthImportIdentityDialog();
+    explicit QgsAuthImportIdentityDialog( QgsAuthImportIdentityDialog::IdentityType identitytype, QWidget *parent SIP_TRANSFERTHIS = nullptr );
 
-    /** Get identity type */
+    //! Gets identity type
     QgsAuthImportIdentityDialog::IdentityType identityType();
 
-    /** Get certificate/key bundle to be imported.
-     * @note not available in Python bindings
+    /**
+     * Gets certificate/key bundle to be imported.
+     * \note not available in Python bindings
      */
-    const QPair<QSslCertificate, QSslKey> certBundleToImport();
+    const QPair<QSslCertificate, QSslKey> certBundleToImport() SIP_SKIP;
 
-    /** Get certificate/key bundle to be imported as a PKI bundle object */
+    //! Gets certificate/key bundle to be imported as a PKI bundle object
     const QgsPkiBundle pkiBundleToImport() { return mPkiBundle; }
 
   private slots:
@@ -80,24 +82,21 @@ class GUI_EXPORT QgsAuthImportIdentityDialog : public QDialog, private Ui::QgsAu
     void validateIdentity();
 
 
-
     void clearValidation();
-    void writeValidation( const QString &msg,
-                          QgsAuthImportIdentityDialog::Validity valid,
-                          bool append = false );
+    void writeValidation( const QString &msg, QgsAuthImportIdentityDialog::Validity valid, bool append = false );
 
     // Cert Identity - PkiPaths
-    void on_lePkiPathsKeyPass_textChanged( const QString &pass );
-    void on_chkPkiPathsPassShow_stateChanged( int state );
+    void lePkiPathsKeyPass_textChanged( const QString &pass );
+    void chkPkiPathsPassShow_stateChanged( int state );
 
-    void on_btnPkiPathsCert_clicked();
-    void on_btnPkiPathsKey_clicked();
+    void btnPkiPathsCert_clicked();
+    void btnPkiPathsKey_clicked();
 
     // Cert Identity - PkiPkcs#12
-    void on_lePkiPkcs12KeyPass_textChanged( const QString &pass );
-    void on_chkPkiPkcs12PassShow_stateChanged( int state );
+    void lePkiPkcs12KeyPass_textChanged( const QString &pass );
+    void chkPkiPkcs12PassShow_stateChanged( int state );
 
-    void on_btnPkiPkcs12Bundle_clicked();
+    void btnPkiPkcs12Bundle_clicked();
 
   private:
     bool validateBundle();
@@ -105,17 +104,17 @@ class GUI_EXPORT QgsAuthImportIdentityDialog : public QDialog, private Ui::QgsAu
     bool validatePkiPkcs12();
 
     void fileFound( bool found, QWidget *widget );
-    QString getOpenFileName( const QString& title, const QString& extfilter );
+    QString getOpenFileName( const QString &title, const QString &extfilter );
 
-    QPushButton* okButton();
+    QPushButton *okButton();
 
-    QgsAuthImportIdentityDialog::IdentityType  mIdentityType;
+    QgsAuthImportIdentityDialog::IdentityType mIdentityType;
     QPair<QSslCertificate, QSslKey> mCertBundle;
     QgsPkiBundle mPkiBundle;
 
     bool mDisabled;
-    QVBoxLayout *mAuthNotifyLayout;
-    QLabel *mAuthNotify;
+    QVBoxLayout *mAuthNotifyLayout = nullptr;
+    QLabel *mAuthNotify = nullptr;
 };
 
 #endif // QGSAUTHIMPORTIDENTITYDIALOG_H
