@@ -18,23 +18,24 @@
 #include "qgis_sip.h"
 #include "qgsnumericformat.h"
 #include "qgspanelwidget.h"
+#include "qgsexpressioncontextgenerator.h"
 #include <memory>
 #include <QDialog>
 
 class QgsFractionNumericFormat;
+class QgsExpressionBasedNumericFormat;
 
 /**
  * \ingroup gui
  * \class QgsNumericFormatWidget
- * \brief Base class for widgets which allow control over the properties of QgsNumericFormat subclasses
+ * \brief Base class for widgets which allow control over the properties of QgsNumericFormat subclasses.
  * \since QGIS 3.12
  */
-class GUI_EXPORT QgsNumericFormatWidget : public QgsPanelWidget
+class GUI_EXPORT QgsNumericFormatWidget : public QgsPanelWidget, public QgsExpressionContextGenerator
 {
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsNumericFormatWidget.
      */
@@ -57,6 +58,16 @@ class GUI_EXPORT QgsNumericFormatWidget : public QgsPanelWidget
      */
     virtual QgsNumericFormat *format() = 0 SIP_TRANSFERBACK;
 
+    /**
+     * Register an expression context generator class that will be used to retrieve
+     * an expression context for the widget when required.
+     *
+     * \since QGIS 3.40
+     */
+    void registerExpressionContextGenerator( QgsExpressionContextGenerator *generator );
+
+    QgsExpressionContext createExpressionContext() const override;
+
   signals:
 
     /**
@@ -64,6 +75,8 @@ class GUI_EXPORT QgsNumericFormatWidget : public QgsPanelWidget
      */
     void changed();
 
+  private:
+    QgsExpressionContextGenerator *mExpressionContextGenerator = nullptr;
 };
 
 
@@ -74,7 +87,7 @@ class QgsBasicNumericFormat;
 /**
  * \ingroup gui
  * \class QgsBasicNumericFormatWidget
- * \brief A widget which allow control over the properties of a QgsBasicNumericFormat.
+ * \brief A widget which allows control over the properties of a QgsBasicNumericFormat.
  * \since QGIS 3.12
  */
 class GUI_EXPORT QgsBasicNumericFormatWidget : public QgsNumericFormatWidget, private Ui::QgsBasicNumericFormatWidgetBase
@@ -82,21 +95,19 @@ class GUI_EXPORT QgsBasicNumericFormatWidget : public QgsNumericFormatWidget, pr
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsBasicNumericFormatWidget, initially showing the specified \a format.
      */
     QgsBasicNumericFormatWidget( const QgsNumericFormat *format, QWidget *parent SIP_TRANSFERTHIS = nullptr );
     ~QgsBasicNumericFormatWidget() override;
 
-    void setFormat( QgsNumericFormat *format ) override;
+    void setFormat( QgsNumericFormat *format ) final;
 
-    QgsNumericFormat *format() override SIP_FACTORY;
+    QgsNumericFormat *format() final SIP_FACTORY;
 
   private:
-    std::unique_ptr< QgsBasicNumericFormat > mFormat;
+    std::unique_ptr<QgsBasicNumericFormat> mFormat;
     bool mBlockSignals = false;
-
 };
 
 #include "ui_qgsbearingnumericformatwidgetbase.h"
@@ -106,7 +117,7 @@ class QgsBearingNumericFormat;
 /**
  * \ingroup gui
  * \class QgsBearingNumericFormatWidget
- * \brief A widget which allow control over the properties of a QgsBearingNumericFormat.
+ * \brief A widget which allows control over the properties of a QgsBearingNumericFormat.
  * \since QGIS 3.12
  */
 class GUI_EXPORT QgsBearingNumericFormatWidget : public QgsNumericFormatWidget, private Ui::QgsBearingNumericFormatWidgetBase
@@ -114,28 +125,26 @@ class GUI_EXPORT QgsBearingNumericFormatWidget : public QgsNumericFormatWidget,
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsBearingNumericFormatWidget, initially showing the specified \a format.
      */
     QgsBearingNumericFormatWidget( const QgsNumericFormat *format, QWidget *parent SIP_TRANSFERTHIS = nullptr );
     ~QgsBearingNumericFormatWidget() override;
 
-    void setFormat( QgsNumericFormat *format ) override;
+    void setFormat( QgsNumericFormat *format ) final;
 
-    QgsNumericFormat *format() override SIP_FACTORY;
+    QgsNumericFormat *format() final SIP_FACTORY;
 
   private:
-    std::unique_ptr< QgsBearingNumericFormat > mFormat;
+    std::unique_ptr<QgsBearingNumericFormat> mFormat;
     bool mBlockSignals = false;
-
 };
 
 
 /**
  * \ingroup gui
  * \class QgsBearingNumericFormatDialog
- * \brief A dialog which allow control over the properties of a QgsBearingNumericFormat.
+ * \brief A dialog which allows control over the properties of a QgsBearingNumericFormat.
  * \since QGIS 3.12
  */
 class GUI_EXPORT QgsBearingNumericFormatDialog : public QDialog
@@ -143,7 +152,6 @@ class GUI_EXPORT QgsBearingNumericFormatDialog : public QDialog
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsBearingNumericFormatDialog, initially showing the specified \a format.
      */
@@ -157,7 +165,6 @@ class GUI_EXPORT QgsBearingNumericFormatDialog : public QDialog
     QgsBearingNumericFormat *format() SIP_FACTORY;
 
   private:
-
     QgsBearingNumericFormatWidget *mWidget = nullptr;
 };
 
@@ -169,7 +176,7 @@ class QgsGeographicCoordinateNumericFormat;
 /**
  * \ingroup gui
  * \class QgsGeographicCoordinateNumericFormatWidget
- * \brief A widget which allow control over the properties of a QgsGeographicCoordinateNumericFormat.
+ * \brief A widget which allows control over the properties of a QgsGeographicCoordinateNumericFormat.
  * \since QGIS 3.26
  */
 class GUI_EXPORT QgsGeographicCoordinateNumericFormatWidget : public QgsNumericFormatWidget, private Ui::QgsGeographicCoordinateNumericFormatWidgetBase
@@ -177,28 +184,26 @@ class GUI_EXPORT QgsGeographicCoordinateNumericFormatWidget : public QgsNumericF
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsGeographicCoordinateNumericFormatWidget, initially showing the specified \a format.
      */
     QgsGeographicCoordinateNumericFormatWidget( const QgsNumericFormat *format, bool hidePrecisionControl = false, QWidget *parent SIP_TRANSFERTHIS = nullptr );
     ~QgsGeographicCoordinateNumericFormatWidget() override;
 
-    void setFormat( QgsNumericFormat *format ) override;
+    void setFormat( QgsNumericFormat *format ) final;
 
-    QgsNumericFormat *format() override SIP_FACTORY;
+    QgsNumericFormat *format() final SIP_FACTORY;
 
   private:
-    std::unique_ptr< QgsGeographicCoordinateNumericFormat > mFormat;
+    std::unique_ptr<QgsGeographicCoordinateNumericFormat> mFormat;
     bool mBlockSignals = false;
-
 };
 
 
 /**
  * \ingroup gui
  * \class QgsGeographicCoordinateNumericFormatDialog
- * \brief A dialog which allow control over the properties of a QgsGeographicCoordinateNumericFormat.
+ * \brief A dialog which allows control over the properties of a QgsGeographicCoordinateNumericFormat.
  * \since QGIS 3.26
  */
 class GUI_EXPORT QgsGeographicCoordinateNumericFormatDialog : public QDialog
@@ -206,7 +211,6 @@ class GUI_EXPORT QgsGeographicCoordinateNumericFormatDialog : public QDialog
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsGeographicCoordinateNumericFormatDialog, initially showing the specified \a format.
      */
@@ -220,12 +224,10 @@ class GUI_EXPORT QgsGeographicCoordinateNumericFormatDialog : public QDialog
     QgsGeographicCoordinateNumericFormat *format() SIP_FACTORY;
 
   private:
-
     QgsGeographicCoordinateNumericFormatWidget *mWidget = nullptr;
 };
 
 
-
 #include "ui_qgscurrencynumericformatwidgetbase.h"
 
 class QgsCurrencyNumericFormat;
@@ -233,7 +235,7 @@ class QgsCurrencyNumericFormat;
 /**
  * \ingroup gui
  * \class QgsCurrencyNumericFormatWidget
- * \brief A widget which allow control over the properties of a QgsCurrencyNumericFormat.
+ * \brief A widget which allows control over the properties of a QgsCurrencyNumericFormat.
  * \since QGIS 3.12
  */
 class GUI_EXPORT QgsCurrencyNumericFormatWidget : public QgsNumericFormatWidget, private Ui::QgsCurrencyNumericFormatWidgetBase
@@ -241,21 +243,19 @@ class GUI_EXPORT QgsCurrencyNumericFormatWidget : public QgsNumericFormatWidget,
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsCurrencyNumericFormatWidget, initially showing the specified \a format.
      */
     QgsCurrencyNumericFormatWidget( const QgsNumericFormat *format, QWidget *parent SIP_TRANSFERTHIS = nullptr );
     ~QgsCurrencyNumericFormatWidget() override;
 
-    void setFormat( QgsNumericFormat *format ) override;
+    void setFormat( QgsNumericFormat *format ) final;
 
-    QgsNumericFormat *format() override SIP_FACTORY;
+    QgsNumericFormat *format() final SIP_FACTORY;
 
   private:
-    std::unique_ptr< QgsCurrencyNumericFormat > mFormat;
+    std::unique_ptr<QgsCurrencyNumericFormat> mFormat;
     bool mBlockSignals = false;
-
 };
 
 
@@ -266,7 +266,7 @@ class QgsPercentageNumericFormat;
 /**
  * \ingroup gui
  * \class QgsPercentageNumericFormatWidget
- * \brief A widget which allow control over the properties of a QgsPercentageNumericFormat.
+ * \brief A widget which allows control over the properties of a QgsPercentageNumericFormat.
  * \since QGIS 3.12
  */
 class GUI_EXPORT QgsPercentageNumericFormatWidget : public QgsNumericFormatWidget, private Ui::QgsPercentageNumericFormatWidgetBase
@@ -274,25 +274,22 @@ class GUI_EXPORT QgsPercentageNumericFormatWidget : public QgsNumericFormatWidge
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsPercentageNumericFormatWidget, initially showing the specified \a format.
      */
     QgsPercentageNumericFormatWidget( const QgsNumericFormat *format, QWidget *parent SIP_TRANSFERTHIS = nullptr );
     ~QgsPercentageNumericFormatWidget() override;
 
-    void setFormat( QgsNumericFormat *format ) override;
+    void setFormat( QgsNumericFormat *format ) final;
 
-    QgsNumericFormat *format() override SIP_FACTORY;
+    QgsNumericFormat *format() final SIP_FACTORY;
 
   private:
-    std::unique_ptr< QgsPercentageNumericFormat > mFormat;
+    std::unique_ptr<QgsPercentageNumericFormat> mFormat;
     bool mBlockSignals = false;
-
 };
 
 
-
 #include "ui_qgsscientificnumericformatwidgetbase.h"
 
 class QgsScientificNumericFormat;
@@ -300,7 +297,7 @@ class QgsScientificNumericFormat;
 /**
  * \ingroup gui
  * \class QgsScientificNumericFormatWidget
- * \brief A widget which allow control over the properties of a QgsScientificNumericFormat.
+ * \brief A widget which allows control over the properties of a QgsScientificNumericFormat.
  * \since QGIS 3.12
  */
 class GUI_EXPORT QgsScientificNumericFormatWidget : public QgsNumericFormatWidget, private Ui::QgsScientificNumericFormatWidgetBase
@@ -308,21 +305,19 @@ class GUI_EXPORT QgsScientificNumericFormatWidget : public QgsNumericFormatWidge
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsScientificNumericFormatWidget, initially showing the specified \a format.
      */
     QgsScientificNumericFormatWidget( const QgsNumericFormat *format, QWidget *parent SIP_TRANSFERTHIS = nullptr );
     ~QgsScientificNumericFormatWidget() override;
 
-    void setFormat( QgsNumericFormat *format ) override;
+    void setFormat( QgsNumericFormat *format ) final;
 
-    QgsNumericFormat *format() override SIP_FACTORY;
+    QgsNumericFormat *format() final SIP_FACTORY;
 
   private:
-    std::unique_ptr< QgsScientificNumericFormat > mFormat;
+    std::unique_ptr<QgsScientificNumericFormat> mFormat;
     bool mBlockSignals = false;
-
 };
 
 
@@ -331,7 +326,7 @@ class GUI_EXPORT QgsScientificNumericFormatWidget : public QgsNumericFormatWidge
 /**
  * \ingroup gui
  * \class QgsFractionNumericFormatWidget
- * \brief A widget which allow control over the properties of a QgsFractionNumericFormat.
+ * \brief A widget which allows control over the properties of a QgsFractionNumericFormat.
  * \since QGIS 3.14
  */
 class GUI_EXPORT QgsFractionNumericFormatWidget : public QgsNumericFormatWidget, private Ui::QgsFractionNumericFormatWidgetBase
@@ -339,20 +334,49 @@ class GUI_EXPORT QgsFractionNumericFormatWidget : public QgsNumericFormatWidget,
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsFractionNumericFormatWidget, initially showing the specified \a format.
      */
     QgsFractionNumericFormatWidget( const QgsNumericFormat *format, QWidget *parent SIP_TRANSFERTHIS = nullptr );
     ~QgsFractionNumericFormatWidget() override;
 
-    void setFormat( QgsNumericFormat *format ) override;
+    void setFormat( QgsNumericFormat *format ) final;
 
-    QgsNumericFormat *format() override SIP_FACTORY;
+    QgsNumericFormat *format() final SIP_FACTORY;
 
   private:
-    std::unique_ptr< QgsFractionNumericFormat > mFormat;
+    std::unique_ptr<QgsFractionNumericFormat> mFormat;
     bool mBlockSignals = false;
+};
 
+
+#include "ui_qgsexpressionbasednumericformatwidgetbase.h"
+
+/**
+ * \ingroup gui
+ * \class QgsExpressionBasedNumericFormatWidget
+ * \brief A widget which allows control over the properties of a QgsExpressionBasedNumericFormat.
+ * \since QGIS 3.40
+ */
+class GUI_EXPORT QgsExpressionBasedNumericFormatWidget : public QgsNumericFormatWidget, private Ui::QgsExpressionBasedNumericFormatWidgetBase
+{
+    Q_OBJECT
+
+  public:
+    /**
+     * Constructor for QgsExpressionBasedNumericFormatWidget, initially showing the specified \a format.
+     */
+    QgsExpressionBasedNumericFormatWidget( const QgsNumericFormat *format, QWidget *parent SIP_TRANSFERTHIS = nullptr );
+    ~QgsExpressionBasedNumericFormatWidget() override;
+
+    QgsExpressionContext createExpressionContext() const final;
+
+    void setFormat( QgsNumericFormat *format ) final;
+
+    QgsNumericFormat *format() final SIP_FACTORY;
+
+  private:
+    std::unique_ptr<QgsExpressionBasedNumericFormat> mFormat;
+    bool mBlockSignals = false;
 };
 #endif // QGSNUMERICFORMATWIDGET_H
